exceptiontools.MarkError
========================

.. abjad-lineage:: abjad.tools.exceptiontools.MarkError.MarkError

.. autoclass:: abjad.tools.exceptiontools.MarkError.MarkError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.MarkError.MarkError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MarkError.MarkError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MarkError.MarkError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MarkError.MarkError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MarkError.MarkError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MarkError.MarkError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MarkError.MarkError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MarkError.MarkError.__unicode__
   :noindex:
